``pylang``
==========

**Multiple language/runtime-env installer written in Python for
Debian/Ubuntu based distros**

Version 0.1.0
-------------

Installation
============

Using ``pip``
-------------

``pip install pylang``

Get the latest build from the Source
------------------------------------

-  Clone the repo
   ``git clone https://github.com/harshasrinivas/pylang.git``
-  Run ``python setup.py install``

Options
=======

.. code:: sh

    -h, --help          show this help message and exit
    -i INSTALL, --install INSTALL
                        Get the language or runtime environment to be installed

Usage
=====

``$ pylang -i <language/RE>``

List of languages/REs supported
===============================

-   c
-   c++
-   java
-   nodejs
-   go
-   php
-   r
-   haskell
-   rust
-   ruby
-   erlang
